@@ -90,6 +90,10 @@ gint64 milliseconds_current_start = 0;
 
 guint game_in_progress;
 
+guint tile_width = 80, tile_height = 80;
+guint board_width = 648, board_height = 648;
+#define GRIDWIDTH 1
+
 gint8 pixmaps[8][8] = { {0, 0, 0, 0, 0, 0, 0, 0}
 ,
 {0, 0, 0, 0, 0, 0, 0, 0}
@@ -280,11 +284,11 @@ properties_cb (GtkWidget * widget, gpointer data)
   show_properties_dialog ();
 }
 
-gint
+gboolean
 expose_event (GtkWidget * widget, GdkEventExpose * event)
 {
-  gdk_draw_drawable (widget->window,
-		     widget->style->fg_gc[GTK_WIDGET_STATE (widget)],
+  gdk_draw_drawable (gtk_widget_get_window (widget),
+		     gtk_widget_get_style (widget)->fg_gc[gtk_widget_get_state (widget)],
 		     buffer_pixmap,
 		     event->area.x, event->area.y,
 		     event->area.x, event->area.y,
@@ -300,7 +304,7 @@ configure_event (GtkWidget * widget, GdkEventConfigure * event)
   guint i, j;
 
   if (old_width == event->width && old_height == event->height) {
-    return TRUE;
+    return FALSE;
   } else {
     old_width = event->width;
     old_height = event->height;
@@ -308,14 +312,14 @@ configure_event (GtkWidget * widget, GdkEventConfigure * event)
 
   if (gridGC[0] != 0) {
     gdk_draw_rectangle (buffer_pixmap, gridGC[0], 1,
-			0, 0, BOARDWIDTH, BOARDHEIGHT);
+			0, 0, board_width, board_height);
     for (i = 0; i < 8; i++)
       for (j = 0; j < 8; j++)
 	gui_draw_pixmap_buffer (pixmaps[i][j], i, j);
     gui_draw_grid ();
   }
 
-  return TRUE;
+  return FALSE;
 }
 
 gint
@@ -333,8 +337,8 @@ button_press_event (GtkWidget * widget, GdkEventButton * event)
     return TRUE;
 
   if (event->button == 1) {
-    x = event->x / (TILEWIDTH + GRIDWIDTH);
-    y = event->y / (TILEHEIGHT + GRIDWIDTH);
+    x = event->x / (tile_width + GRIDWIDTH);
+    y = event->y / (tile_height + GRIDWIDTH);
     if (ggz_network_mode && player_id == whose_turn
 	&& is_valid_move (x, y, whose_turn)) {
 #ifdef GGZ_CLIENT
@@ -354,23 +358,23 @@ button_press_event (GtkWidget * widget, GdkEventButton * event)
 void
 gui_draw_pixmap (gint which, gint x, gint y)
 {
-  gdk_draw_drawable (drawing_area->window, gridGC[0], tiles_pixmap,
-		     (which % 8) * TILEWIDTH, (which / 8) * TILEHEIGHT,
-		     x * (TILEWIDTH + GRIDWIDTH),
-		     y * (TILEHEIGHT + GRIDWIDTH), TILEWIDTH, TILEHEIGHT);
+  gdk_draw_drawable (gtk_widget_get_window (drawing_area), gridGC[0], tiles_pixmap,
+		     (which % 8) * tile_width, (which / 8) * tile_height,
+		     x * (tile_width + GRIDWIDTH),
+		     y * (tile_height + GRIDWIDTH), tile_width, tile_height);
   gdk_draw_drawable (buffer_pixmap, gridGC[0], tiles_pixmap,
-		     (which % 8) * TILEWIDTH, (which / 8) * TILEHEIGHT,
-		     x * (TILEWIDTH + GRIDWIDTH),
-		     y * (TILEHEIGHT + GRIDWIDTH), TILEWIDTH, TILEHEIGHT);
+		     (which % 8) * tile_width, (which / 8) * tile_height,
+		     x * (tile_width + GRIDWIDTH),
+		     y * (tile_height + GRIDWIDTH), tile_width, tile_height);
 }
 
 void
 gui_draw_pixmap_buffer (gint which, gint x, gint y)
 {
   gdk_draw_drawable (buffer_pixmap, gridGC[0], tiles_pixmap,
-		     (which % 8) * TILEWIDTH, (which / 8) * TILEHEIGHT,
-		     x * (TILEWIDTH + GRIDWIDTH),
-		     y * (TILEHEIGHT + GRIDWIDTH), TILEWIDTH, TILEHEIGHT);
+		     (which % 8) * tile_width, (which / 8) * tile_height,
+		     x * (tile_width + GRIDWIDTH),
+		     y * (tile_height + GRIDWIDTH), tile_width, tile_height);
 }
 
 void
@@ -380,15 +384,15 @@ gui_draw_grid (void)
 
   for (i = 1; i < 8; i++) {
     gdk_draw_line (buffer_pixmap, gridGC[grid],
-		   i * BOARDWIDTH / 8 - 1, 0,
-		   i * BOARDWIDTH / 8 - 1, BOARDHEIGHT);
+		   i * board_width / 8 - 1, 0,
+		   i * board_width / 8 - 1, board_height);
     gdk_draw_line (buffer_pixmap, gridGC[grid],
-		   0, i * BOARDHEIGHT / 8 - 1,
-		   BOARDWIDTH, i * BOARDHEIGHT / 8 - 1);
+		   0, i * board_height / 8 - 1,
+		   board_width, i * board_height / 8 - 1);
   }
 
-  gdk_draw_drawable (drawing_area->window, gridGC[0], buffer_pixmap,
-		     0, 0, 0, 0, BOARDWIDTH, BOARDHEIGHT);
+  gdk_draw_drawable (gtk_widget_get_window (drawing_area), gridGC[0],
+		     buffer_pixmap, 0, 0, 0, 0, board_width, board_height);
 }
 
 void
@@ -423,6 +427,18 @@ load_pixmaps (void)
     error = NULL;
   }
 
+  tile_width = gdk_pixbuf_get_width (image) / 8;
+  tile_height = gdk_pixbuf_get_height (image) / 4;
+  board_width = (tile_width+GRIDWIDTH) * 8;
+  board_height = (tile_height+GRIDWIDTH) * 8;
+  if (buffer_pixmap)
+    g_object_unref (buffer_pixmap);
+  gtk_widget_realize (drawing_area);
+  buffer_pixmap = gdk_pixmap_new (gtk_widget_get_window (drawing_area),
+                                  board_width, board_height, -1);
+  gtk_widget_set_size_request (GTK_WIDGET (drawing_area),
+			       board_width, board_height);
+
   gdk_pixbuf_render_pixmap_and_mask_for_colormap (image,
 						  gdk_colormap_get_system (),
 						  &tiles_pixmap,
@@ -734,20 +750,20 @@ set_bg_color (void)
 {
   GdkImage *tmpimage;
   GdkColor bgcolor;
-
+    
   tmpimage = gdk_drawable_get_image (tiles_pixmap, 0, 0, 1, 1);
   bgcolor.pixel = gdk_image_get_pixel (tmpimage, 0, 0);
-  gdk_window_set_background (drawing_area->window, &bgcolor);
+  gdk_window_set_background (gtk_widget_get_window (drawing_area), &bgcolor);
 
   if (gridGC[0])
     g_object_unref (gridGC[0]);
-  gridGC[0] = gdk_gc_new (drawing_area->window);
+  gridGC[0] = gdk_gc_new (gtk_widget_get_window (drawing_area));
   if (gridGC[1])
     g_object_unref (gridGC[1]);
-  gridGC[1] = gdk_gc_new (drawing_area->window);
+  gridGC[1] = gdk_gc_new (gtk_widget_get_window (drawing_area));
 
-  gdk_gc_copy (gridGC[0], drawing_area->style->bg_gc[0]);
-  gdk_gc_copy (gridGC[1], drawing_area->style->bg_gc[0]);
+  gdk_gc_copy (gridGC[0], gtk_widget_get_style (drawing_area)->bg_gc[0]);
+  gdk_gc_copy (gridGC[1], gtk_widget_get_style (drawing_area)->bg_gc[0]);
 
   gdk_gc_set_background (gridGC[0], &bgcolor);
   gdk_gc_set_foreground (gridGC[0], &bgcolor);
@@ -774,7 +790,7 @@ save_state_cb (EggSMClient *client,
   gint argc;
   gint xpos, ypos;
 
-  gdk_window_get_origin (window->window, &xpos, &ypos);
+  gdk_window_get_origin (gtk_widget_get_window (window), &xpos, &ypos);
 
   argc = 0;
   argv[argc++] = g_get_prgname ();
@@ -922,9 +938,6 @@ create_window (void)
   gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), MAIN_PAGE);
   gtk_box_pack_start (GTK_BOX (vbox), notebook, FALSE, FALSE, 0);
 
-  gtk_widget_set_size_request (GTK_WIDGET (drawing_area),
-			       BOARDWIDTH, BOARDHEIGHT);
-
   g_signal_connect (G_OBJECT (drawing_area), "expose_event",
 		    G_CALLBACK (expose_event), NULL);
   g_signal_connect (G_OBJECT (window), "configure_event",
@@ -1028,20 +1041,18 @@ main (int argc, char **argv)
 
   create_window ();
 
-  gtk_widget_show (window);
-  buffer_pixmap = gdk_pixmap_new (drawing_area->window,
-				  BOARDWIDTH, BOARDHEIGHT, -1);
-
   load_properties ();
 
   load_pixmaps ();
 
+  gtk_widget_show (window);
+
 #ifdef GGZ_CLIENT
   network_init ();
 #endif /* GGZ_CLIENT */
 
   if (session_xpos >= 0 && session_ypos >= 0) {
-    gdk_window_move (window->window, session_xpos, session_ypos);
+    gdk_window_move (gtk_widget_get_window (window), session_xpos, session_ypos);
   }
 
   set_bg_color ();
